import React, { useRef, useState } from 'react';
import moment from 'moment';
import { Button, Modal, Form, Input } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import PageTable from '@/components/PageTable'
import BanjiSearch from '@/components/BanjiSearch';
import { getInvoiceDetailHistoryList } from '@/services/invoiceDetail'

export default (props) => {
  const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };
  const [form] = Form.useForm();
  const FormItem = Form.Item;
  const [editModal, setEditModal] = useState(false);
  const actionRef = useRef();

  const handelModel = (val) => {
    form.setFieldsValue(val);
    setEditModal(true);
  };

  const onCancel = () => {
    form.resetFields();
    setEditModal(false);
  };

  const columns = [
    {
      title: '班次名称',
      dataIndex: 'invoiceId',
      key: 'invoiceId',
      search: true,
      hideInTable: true,
      renderFormItem: () => (
        <BanjiSearch placeholder='请输入班次名称' />
      ),
      formItemProps: {
        rules: [
          {
            required: true,
            message: '请输入班次名称',
          }
        ],
      }
    },
    {
      title: '开票单位',
      dataIndex: 'orgName',
      key: 'orgName',
      search: false,
    },
    {
      title: '人员姓名',
      dataIndex: 'personName',
      key: 'personName',
      search: true,
      formItemProps: {
        rules: [
          {
            required: true,
            message: '请输入人员姓名',
          }
        ],
      }
    },
    {
      title: '提交时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t) => t ? moment(t).format('YYYY-MM-DD HH:mm') : '-',
      search: false
    },
    {
      title: '操作',
      valueType: 'option',
      key: 'option',
      ellipsis: true,
      render: (_, record) => [
        <Button style={{ padding: 0 }} type="link" key={1} onClick={() => handelModel(record)}>
          详情
        </Button>
      ]
    },
  ]
  return (
    <PageHeaderWrapper>
      <PageTable
        request={getInvoiceDetailHistoryList}
        columns={columns}
        options={false}
        onCancel={onCancel}
        actionRef={actionRef}
        manualRequest={true}
        form={{ ignoreRules: false }}
      />
      <Modal
        forceRender
        title='历史详情'
        visible={editModal}
        keyboard={false}
        maskClosable={false}
        destroyOnClose={true}
        onCancel={onCancel}
        footer={null}
      >
        <Form {...formItemLayout} form={form}>
          <FormItem label="开票单位" name="orgName">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="纳税号" name="taxNo">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="单位地址" name="address">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="单位电话" name="phone">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="开户银行" name="bankName">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="是否合开" name="mergeRemark">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="收件人姓名" name="mailUser">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="收件人电话" name="mailPhone">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label="收件人地址" name="mailAddress">
            <Input bordered={false} disabled={false} />
          </FormItem>
          <FormItem label=" " colon={false}>
            <Button
              type="primary"
              onClick={onCancel}
              style={{ marginLeft: '20em' }}
            >
              关闭
            </Button>
          </FormItem>
        </Form>
      </Modal>
    </PageHeaderWrapper>
  )
}
